# Generated by Django 2.0 on 2018-01-02 21:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("edc_registration", "0009_auto_20171228_1816")]

    operations = [
        migrations.AddField(
            model_name="registeredsubject",
            name="consent_datetime",
            field=models.DateTimeField(blank=True, null=True),
        )
    ]



# Generated by Django 3.0.4 on 2020-05-12 21:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_registration", "0020_auto_20191024_1000"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="registeredsubject",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ["subject_identifier"],
                "permissions": (
                    ("display_firstname", "Can display first name"),
                    ("display_lastname", "Can display last name"),
                    ("display_dob", "Can display DOB"),
                    ("display_identity", "Can display identity number"),
                    ("display_initials", "Can display initials"),
                ),
                "verbose_name": "Registered Subject",
            },
        ),
    ]



# Generated by Django 3.2.4 on 2021-08-01 17:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('edc_registration', '0021_auto_20200513_0023'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalregisteredsubject',
            name='identity_or_pk',
        ),
        migrations.RemoveField(
            model_name='registeredsubject',
            name='identity_or_pk',
        ),
    ]



from django.apps import apps as django_apps
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist


def get_registered_subject_model_name():
    return getattr(
        settings,
        "EDC_REGISTRATION_REGISTERED_SUBJECT_MODEL",
        "edc_registration.registeredsubject",
    )


def get_registered_subject_model_cls():
    return django_apps.get_model(get_registered_subject_model_name())


def get_registered_subject(subject_identifier):
    try:
        registered_subject = get_registered_subject_model_cls().get(
            subject_identifier=subject_identifier
        )
    except ObjectDoesNotExist:
        registered_subject = None
    return registered_subject



# Generated by Django 2.0.1 on 2018-01-16 13:28

import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("edc_registration", "0011_auto_20180116_1411")]

    operations = [
        migrations.AlterModelManagers(
            name="registeredsubject",
            managers=[("on_site", edc_sites.models.CurrentSiteManager())],
        )
    ]



# Generated by Django 3.2.11 on 2022-04-12 18:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('edc_registration', '0022_auto_20210801_2021'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='registeredsubject',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'), 'get_latest_by': 'modified', 'ordering': ['subject_identifier'], 'permissions': (('display_firstname', 'Can display first name'), ('display_lastname', 'Can display last name'), ('display_dob', 'Can display DOB'), ('display_identity', 'Can display identity number'), ('display_initials', 'Can display initials')), 'verbose_name': 'Registered Subject', 'verbose_name_plural': 'Registered Subjects'},
        ),
    ]



import sys
from datetime import datetime

from dateutil.tz import gettz
from django.apps import AppConfig as DjangoAppConfig
from django.apps import apps as django_apps
from django.conf import settings


class AppConfig(DjangoAppConfig):
    name = "edc_registration"
    verbose_name = "Edc Registration"
    app_label = "edc_registration"
    has_exportable_data = True
    include_in_administration_section = True

    def ready(self):
        sys.stdout.write(f"Loading {self.verbose_name} ...\n")
        sys.stdout.write(f"  * using {self.app_label}.registeredsubject\n")
        sys.stdout.write(f" Done loading {self.verbose_name}.\n")

    @property
    def model(self):
        return django_apps.get_model(self.app_label, "registeredsubject")


if "edc_registration" in settings.APP_NAME:

    from edc_protocol.apps import AppConfig as BaseEdcProtocolAppConfig

    class EdcProtocolAppConfig(BaseEdcProtocolAppConfig):
        protocol = "BHP092"
        protocol_name = "Ambition"
        protocol_number = "092"
        protocol_title = ""
        site_code = "40"
        site_name = "Gaborone"
        study_open_datetime = datetime(2016, 12, 31, 0, 0, 0, tzinfo=gettz("UTC"))
        study_close_datetime = datetime(2019, 12, 31, 23, 59, 59, tzinfo=gettz("UTC"))



from django.contrib import admin
from edc_auth.auth_objects import PII, PII_VIEW
from edc_model_admin import audit_fields
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin


class RegisteredSubjectModelAdminMixin(ModelAdminSubjectDashboardMixin, admin.ModelAdmin):

    ordering = ("registration_datetime",)

    date_hierarchy = "registration_datetime"

    instructions = []

    def show_pii(self, request):
        return request.user.groups.filter(name__in=[PII, PII_VIEW]).exists()

    def get_fieldsets(self, request, obj=None):
        """
        Hook for specifying fieldsets.
        """
        if self.fieldsets:
            if self.show_pii(request):
                return self.fieldsets
            else:
                return self.fieldsets_no_pii
        return [(None, {"fields": self.get_fields(request, obj)})]

    def get_readonly_fields(self, request, obj=None):
        readonly_fields = super().get_readonly_fields(request, obj=obj)
        return (
            list(readonly_fields)
            + [
                "subject_identifier",
                "sid",
                "first_name",
                "last_name",
                "initials",
                "dob",
                "gender",
                "subject_type",
                "registration_status",
                "identity",
                "screening_identifier",
                "screening_datetime",
                "registration_datetime",
                "randomization_datetime",
                "consent_datetime",
            ]
            + list(audit_fields)
        )

    def get_list_display(self, request):

        if self.show_pii(request):
            list_display = [
                "subject_identifier",
                "dashboard",
                "first_name",
                "initials",
                "gender",
                "subject_type",
                "sid",
                "registration_status",
                "site",
                "user_created",
                "created",
            ]
        else:
            list_display = [
                "subject_identifier",
                "dashboard",
                "gender",
                "subject_type",
                "sid",
                "registration_status",
                "site",
                "user_created",
                "created",
            ]
        return list_display + list(super().get_list_display(request))

    def get_list_filter(self, request):
        super().get_list_filter(request)
        if self.show_pii(request):
            fields = [
                "subject_type",
                "registration_status",
                "screening_datetime",
                "registration_datetime",
                "gender",
                "site",
                "hostname_created",
            ]
        else:
            fields = [
                "subject_type",
                "registration_status",
                "screening_datetime",
                "registration_datetime",
                "site",
                "hostname_created",
            ]
        self.list_filter = [f for f in fields if f not in self.list_filter] + list(
            self.list_filter
        )
        return self.list_filter

    def get_search_fields(self, request):
        if self.show_pii(request):
            search_fields = [
                "subject_identifier",
                "first_name",
                "initials",
                "sid",
                "identity",
                "id",
                "screening_identifier",
                "registration_identifier",
            ]
        else:
            search_fields = [
                "subject_identifier",
                "sid",
                "id",
                "screening_identifier",
                "registration_identifier",
            ]
        return search_fields + list(super().get_search_fields(request))



# Generated by Django 2.1 on 2018-08-14 18:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("edc_registration", "0013_auto_20180813_1614")]

    operations = [
        migrations.AlterModelOptions(
            name="registeredsubject",
            options={
                "ordering": ["subject_identifier"],
                "permissions": (
                    ("display_firstname", "Can display first name"),
                    ("display_lastname", "Can display last name"),
                    ("display_dob", "Can display DOB"),
                    ("display_identity", "Can display identity number"),
                    ("display_initials", "Can display initials"),
                ),
                "verbose_name": "Registered Subject",
            },
        )
    ]
